######################################
Thorlabs Pro 8000 modular laser driver
######################################

.. autoclass:: pymeasure.instruments.thorlabs.ThorlabsPro8000
    :members:
    :show-inheritance:
